
*********************
Custom plot functions
*********************

Overview
========

Set axes limits
---------------

.. autosummary::

    GooseMPL.minmax
    GooseMPL.scale_lim
    GooseMPL.set_decade_lims

Ticks
-----

.. autosummary::

    GooseMPL.log_ticks
    GooseMPL.log_xticks
    GooseMPL.log_yticks
    GooseMPL.log_minorticks
    GooseMPL.log_minorxticks
    GooseMPL.log_minoryticks

Plot in relative coordinates
----------------------------

.. autosummary::

    GooseMPL.plot
    GooseMPL.text
    GooseMPL.rel2abs_x
    GooseMPL.rel2abs_y
    GooseMPL.abs2rel_x
    GooseMPL.abs2rel_y

Fit
---

.. autosummary::

    GooseMPL.fit_powerlaw
    GooseMPL.fit_exp
    GooseMPL.fit_linear

Annotate power-law
------------------

.. autosummary::

    GooseMPL.grid_powerlaw
    GooseMPL.plot_powerlaw
    GooseMPL.annotate_powerlaw
    GooseMPL.diagonal_powerlaw

Plot mesh
---------

.. autosummary::

  GooseMPL.patch

(Plot) statistics
-----------------

.. autosummary::

    GooseMPL.histogram
    GooseMPL.histogram_bin_edges
    GooseMPL.histogram_bin_edges_minwidth
    GooseMPL.histogram_bin_edges_mincount
    GooseMPL.histogram_bin_edges_integer
    GooseMPL.histogram_bin_edges2midpoint
    GooseMPL.histogram_norm
    GooseMPL.histogram_cumulative
    GooseMPL.cdf
    GooseMPL.hist
    GooseMPL.random_from_cdf

LaTeX
-----

.. autosummary::

    GooseMPL.latex_float
    GooseMPL.system_has_latex
    GooseMPL.find_latex_font_serif

Styles
------

.. autosummary::

    GooseMPL.subplots
    GooseMPL.savefig
    GooseMPL.close
    GooseMPL.copy_style

Documentation
=============

.. automodule:: GooseMPL
  :members:
